metabind: Combine and summarize meta-analysis objects

View source: R/metabind.R

metabindR Documentation

Combine and summarize meta-analysis objects

Description

This function can be used to combine meta-analysis objects and is, for example, useful to summarize results of various meta-analysis methods or to generate a forest plot with results of several subgroup analyses.

Usage

metabind(
  ...,
  subgroup = NULL,
  name = NULL,
  common = NULL,
  random = NULL,
  prediction = NULL,
  backtransf = NULL,
  outclab = NULL,
  pooled = NULL,
  warn.deprecated = gs("warn.deprecated")
)

Arguments

...

Any number of meta-analysis objects or a single list with meta-analyses.

subgroup

An optional variable to generate a forest plot with subgroups.

name

An optional character vector providing descriptive names for the meta-analysis objects.

common

A logical vector indicating whether results of common effect model should be considered.

random

A logical vector indicating whether results of random effects model should be considered.

prediction

A logical vector indicating whether results of prediction intervals should be considered.

backtransf

A logical indicating whether results should be back transformed in printouts and plots. If backtransf=TRUE (default), results for sm="OR" are printed as odds ratios rather than log odds ratios, for example.

outclab

Outcome label for all meta-analyis objects.

pooled

Deprecated argument (replaced by common and random.

warn.deprecated

A logical indicating whether warnings should be printed if deprecated arguments are used.

Details

This function can be used to combine any number of meta-analysis objects which is useful, for example, to summarize results of various meta-analysis methods or to generate a forest plot with results of several subgroup analyses (see Examples).

Individual study results are not retained with metabind as the function allows to combine meta-analyses from different data sets (e.g., with randomised or observational studies). Individual study results are retained with R function metamerge which can be used to combine results of meta-analyses of the same dataset.

Value

An object of class c("metabind", "meta") with corresponding generic functions (see meta-object).

Author(s)

Guido Schwarzer guido.schwarzer@uniklinik-freiburg.de

See Also

metagen, forest.metabind, metamerge

Examples

data(Fleiss1993cont)

# Add some (fictitious) grouping variables:
#
Fleiss1993cont$age <- c(55, 65, 55, 65, 55)
Fleiss1993cont$region <- c("Europe", "Europe", "Asia", "Asia", "Europe")

ma <- metacont(n.psyc, mean.psyc, sd.psyc, n.cont, mean.cont, sd.cont,
  data = Fleiss1993cont, sm = "SMD")

# Conduct two subgroup analyses
#
ma1 <- update(ma, subgroup = age, subgroup.name = "Age group")
ma2 <- update(ma, subgroup = region, subgroup.name = "Region")

# Combine random effects subgroup meta-analyses and show forest
# plot with subgroup results
#
mb <- metabind(ma1, ma2, common = FALSE)
mb
forest(mb)

# Use various estimation methods for between-study heterogeneity
# variance
#
ma.pm <- update(ma, method.tau = "PM")
ma.dl <- update(ma, method.tau = "DL")
ma.ml <- update(ma, method.tau = "ML")
ma.hs <- update(ma, method.tau = "HS")
ma.sj <- update(ma, method.tau = "SJ")
ma.he <- update(ma, method.tau = "HE")
ma.eb <- update(ma, method.tau = "EB")

# Combine meta-analyses and show results
#
taus <- c("Restricted maximum-likelihood estimator",
  "Paule-Mandel estimator",
  "DerSimonian-Laird estimator",
  "Maximum-likelihood estimator",
  "Hunter-Schmidt estimator",
  "Sidik-Jonkman estimator",
  "Hedges estimator",
  "Empirical Bayes estimator")
#
ma.taus <- metabind(ma, ma.pm, ma.dl, ma.ml, ma.hs, ma.sj, ma.he, ma.eb,
  name = taus, common = FALSE)
ma.taus
forest(ma.taus)


meta documentation built on April 2, 2026, 5:07 p.m.