Changelog#
2.6.0 (2026-03-16)#
Bug fixes:#
Allow maintenance branches to run GHA workflows from
meta.yml@gforcada #337Add workflow_dispatch trigger for generated test-matrix workflows. @mauritsvanrees
Internal:#
Remove outdated GitHub workflow @gforcada
Documentation:#
Add documentation following Diataxis framework @jensens
Tests:#
Add test suite and code coverage @jensens @gforcada
2.5.1 (2026-03-09)#
Bug fixes:#
Bump isort version @gforcada
2.5.0 (2026-03-09)#
New features:#
Update
blackandpyupgradeto use the lowest python version supported from the test matrix @gforcada #285Detect upper bound for setuptools in build-system. For
pkg_resourcesnamespaces, usesetuptools<82, otherwisesetuptools<83. @mauritsvanrees
Bug fixes:#
Add missing newline on news entry files @gforcada
Adjust indentation on gitlab-ci.yml @gforcada
Do not add trailing colons on changes subheadings @gforcada
GHA: Fix platforms input not being passed to docker/build-push-action. @ericof
2.4.0 (2026-02-27)#
New features:#
Add Python 3.14 to the test matrix of Plone 6.2. @mauritsvanrees
Add option
use_test_matrix, default true. When false, don’t use the test matrix.Switch to Debian Trixie, more updates to Python 3.14.
Use Debian Trixie for all Platforms, remove the 3.9 image reference and add more updates Python 3.14 support. [thet]
Bug fixes:#
2.3.2 (2026-02-11)#
Bug fixes:#
Handle repositories without towncrier, when converting them to native namespace @gforcada #312
pin setuptools to version < 82.0.0 in the tox-qa template [testenv:dependencies] this fix
ModuleNotFoundError: No module named 'pkg_resources'if runtox -e dependenciesin a project z3c.dependencychecker is not ready for PEP 420 native namespace @1letter #320
2.3.1 (2025-12-15)#
Bug fixes:#
Remove Python 3.9 from testing matrix as it went EOL @gforcada
Update GHA version pins @gforcada
2.3.0 (2025-12-06)#
New features:#
Replace
pkg_resourcesnamespace with PEP 420 native namespace. Support only Plone 6.2 and Python 3.10+. #3928
2.2.2 (2025-11-11)#
Bug fixes:#
switch-to-pep420script: removesetuptoolsdependency. @mauritsvanrees #3982
2.2.1 (2025-11-08)#
Bug fixes:#
Fix switch to native namespace script to expect
bumpversionto be globally available @gforcada
2.2.0 (2025-11-08)#
New features:#
Add and adapt switch-to-pep420 script from zope meta. #3982
Setup uv in frontend shared workflows – used by repoplone. @ericof
Support github options
extra_linesandextra_lines_after_os_dependencies. @mauritsvanrees
Bug fixes:#
Do not add
test_deps_additionaltocircularandrelease-checktox envs. @mauritsvanrees #293
2.1.0 (2025-09-12)#
New features:#
Support combinations of multiple versions of Plone and Python in tox. @gforcada #234
Add Plone 6.2 on the default test matrix generated by
plone.meta@gforcada #255Add reusable workflows and composite actions to be used with projects generate via Cookieplone. @ericof #277
Test matrix: allow specifying
["*"]as Python list. We replace it with the default Python versions list supported on the given Plone version. @mauritsvanrees
Bug fixes:#
Documentation:#
2.0.0 (2025-02-11)#
New features#
Allow to configure extra options on
i18ndude’spre-commitconfiguration @Akshat2Jain #133Install browsers (for playwright) on packages that run plone.app.robotframework tests @gforcada #155
Allow setting GHA environment variables @ericof #164
Implement conditional towncrier configuration depending on existing
news/folder @petschki #170Allow customizing enabled gitlab-ci jobs @petschki #171
In generated
pyproject.tomlfiles, addbuild-systemrequiringsetuptools68.2+. Also, build the package in isolation, so the build is free to use the requiredsetuptoolsversion. This combination fixes possibleModuleNotFoundErrorsforplone.app.*packages @mauritsvanrees #172Ignore
.*projectin git @wesleybl #179tox: allow to configure what gets intestenvenvironment @gforcada #185Configure
dependabotto get GHA updates. @gforcada #201GHA: Allow to run
tox -e testwith multiple python versions @gforcada #210Made
pytest-plonetest dependency intox.inioptional. Specifyuse_pytest_plone = falseif you don’t want to use it. Also addedcheck_manifest_extra_linesforpyproject.toml, you can use it for specifying corner cases likeignore-bad-ideas@reinout #212Use tomlkit for TOML read/write operations it allow custom regexes with backslahes in meta.toml it is a port of https://github.com/zopefoundation/meta/pull/215 #229
Turn this repository into a proper Python distribution. @gforcada #239
Make
plone.metaan actual python distribution releasable in PyPI @gforcada #248When creating a branch, use the git commit hash from meta repository @gforcada
Bug fixes#
Only run a GHA on Linux, while we wait for a counterpart for Windows @gforcada #180
Moved inline comments in .editorconfig to their own lines: the spec at https://spec.editorconfig.org/#no-inline-comments forbids it @reinout #208
Stop relying on GitHub repository/organization variables @gforcada #210
Preventing lines with only spaces in the generated tox.ini @reinout #212
On
.meta.tomlfile installed byplone.meta, writeplone.meta’s version oncommit-idrather than a commit. We are no longer runningplone.metaout of a checkout, but rather from a release version @gforcada #248Fix
dependabot.ymllocation @gforcada #252Do not track packages on
packages.txtby default @gforcadaEnsure that
prettier’s default line length is respected @gforcadaMark old
shared-workflowsGHA as deprecated @gforcada
Internal#
Add .gitignore @wesleybl #178
Editorconfig: Restructure the frontend config.
Add an xml type to the xml section.
Move the HTML type to the xml section.
This allows more easily for frontend related files except HTML files to be reconfigured for an 4-space indentation. 4 spaces for JS/CSS related code is the default style in Patternslib/Mockup. style @thet #197
Documentation#
Add a note on how to disable i18ndude checks. Add a note on how to apply a customized configuration. @thet #200
1.0.0 (2023-07-12)#
New features:#
Allow passing arguments to
tox -e test. [@mauritsvanrees] #0Run robot tests as well (pass
--alltozope.testrunner) [@mauritsvanrees] #0Generate XML coverage reports. [@gforcada] #0
Handle repositories that do not have
towncrierconfigured. [@petschki] #0Add
skipoption tocodespell. [@petschki] #0Fix deletion of old files. [@mauritsvanrees] #0
Use
pre-committo manage most of QA/linting tools. [@mauritsvanrees] #0Make
toxfail if the environment is not defined. [@mauritsvanrees] #0Allow to install extra dependencies on tox environments. [@gforcada] #0
Allow updating the current branch, rather than creating a new one. [@mauritsvanrees] #0
Update
pre-commitconfiguration. [@ale-rt] #0Allow repositories to not be recorded in
packages.txt. [@gforcada] #0Report branch coverage. [@gforcada] #0
Major update on the documentation. [@gforcada] #0
Decide on standard towncrier snippets. [@gforcada] #2
Do not push repository changes by default. [@gforcada] #3
Do not run
toxin parallel mode, when first configuring a repository. [@gforcada] #4New linting tool: check-manifest. [@gforcada] #6
Use
git ls-filesto get the files that need to be linted. [@gforcada] #11Display project dependencies in a visual graph. [@gforcada] #14
Run distributions’ tests. [@gforcada] #15
Add automatic (towncrier) news entry when configuring a repository. [@gforcada] #20
Keep
setup.metadataandsetup.optionsin .meta.toml. [@mauritsvanrees] #24Add another linter: pyroma. [@gforcada] #28
Analyze package dependencies with
z3c.dependencychecker. [@gforcada] #34New formatter: zpretty. [@gforcada] #35
New linter:
pipforester(find circular dependencies). [@gforcada] #42New linter: check-python-versions [@gforcada] #44
Generate coverage reports. [@gforcada] #45
Support markdown for towncrier news snippets. [@gforcada] #49
Add default dependency mappings for
z3c.dependencychecker. [@gforcada] #52New linter: i18ndude. [@gforcada] #60
Manage
.gitignoreas well. [@gforcada] #62Allow to configure OS dependencies to be installed (for CI jobs). [@gforcada] #65
Allow to specify extra configuration options for
flake8, like exclude files, plugins, etc.. [@gforcada] #71Show coverage reports on GHA job summaries. [@gforcada] #72
Improve documentation of all options, and ensure all options are documented. [@gforcada] #82
Do not rely on a centralized workflow, but rather install shim GHA workflows. [@gforcada] #87
New linter:
twineto ensure repositories are always ready to be released. [@gforcada] #98Automatically detect if
pytestorzope.testrunneris used. [@ericof] #120Add support for GitLab CI. [@gforcada] #131
Allow to extend all sections of
pyproject.toml. [@gforcada] #135Allow to specify a custom constraints.txt for
toxenvironments to use. [@gforcada] #136Allow to specify environment variables on
tox.ini. [@gforcada] #143Allow to specify towncrier issue format. [@ericof] #147
Allow to customize GHA shim. [@ericof] #150
Add
mxdevsupport. [@ericof] #151
Bug fixes:#
Do not ignore
setuptoolsonplone.basemapping. [@mauritsvanrees] #0Use
constrain_package_deps = trueontox.ini. [@mauritsvanrees] #0Fix changelog template to have a leading dot. [@mauritsvanrees] #0
Add
ExtensionClassnamespaces onZopemapping. [@jensens] #0Update
.gitignoredefaults. [@petschki] #0, #111Ignore
tox.inifrom check-manifest. [@gforcada] #5Adjust
flake8configuration to be compatible withblack. [@mauritsvanrees] #23Allow to configure
codespellto ignore some words. [@gforcada] #29Specify, on
pyupgrade, which python version to lint. [@mauritsvanrees] #41Add a missing
codespelldependency. [@gforcada] #47Move
check-manifestconfiguration over topyproject.toml. [@gforcada] #56Improve codespell default configuration options by providing sane defaults. [@gforcada] #57
Enforce
pipforesterto be run always. [@gforcada] #77Do not install dependencies on
z3c.dependencycheckertox environment. [@gforcada] #84Ignore coverage errors when generating reports. [@mauritsvanrees] #110
Update
.editorconfigdefaults. [@ericof] #116Update
.gitignoredefaults. [@ericof] #123